package cz.cuni.amis.pogamut.ut2004.examples.attackbot;

import cz.cuni.amis.pogamut.sposh.context.UT2004Context;
import cz.cuni.amis.pogamut.ut2004.agent.navigation.UT2004PathAutoFixer;
import cz.cuni.amis.pogamut.ut2004.agent.navigation.stuckdetector.UT2004DistanceStuckDetector;
import cz.cuni.amis.pogamut.ut2004.agent.navigation.stuckdetector.UT2004PositionStuckDetector;
import cz.cuni.amis.pogamut.ut2004.agent.navigation.stuckdetector.UT2004TimeStuckDetector;
import cz.cuni.amis.pogamut.ut2004.bot.impl.UT2004Bot;

/**
 * Context for the simple DeathMatch bot.
 */
public class AttackBotContext extends UT2004Context<UT2004Bot> {

    /**
     * AutoFixer monitors movement of agent and when it detects faulty
     * connection in the waypoints, it removes them from navigation logic.
     */
    UT2004PathAutoFixer autoFixer;

    public AttackBotContext(UT2004Bot bot) {
        super("AttackBotContext", bot);
        // IMPORTANT: Various modules of context must be initialized.
        initialize();

        // INITIALIZE CUSTOM MODULES

        pathExecutor.addStuckDetector(new UT2004TimeStuckDetector(bot, 3000, 10000)); // if the bot does not move for 3 seconds, consider that it is stuck / if bot waits for more than 10 seconds, consider that is is stuck
        pathExecutor.addStuckDetector(new UT2004PositionStuckDetector(bot));          // watch over the position history of the bot, if the bot does not move sufficiently enough, consider that it is stuck
        pathExecutor.addStuckDetector(new UT2004DistanceStuckDetector(bot));          // watch over distances to target

        // AutoFixer tries to detect faulty connections between waypoints 
        // in the environment and remove them from navigation planners. 
        // AttackBot is used mostly on small maps, e.g. CTF-1on1-Joust, where 
        // every connection is necessary and its loss will break the navigation.

        //autoFixer = new UT2004PathAutoFixer(bot, pathExecutor, fwMap, navBuilder);
    }
}
